@@ -21,16 +21,18 @@ CONFIG_FILE_PATHS = [
     f"{appdirs.user_config_dir('midas', 'OFFIS')}/{CONFIG_FILE_NAME}",
     f"{getcwd()}/{CONFIG_FILE_NAME}",
 ]
-DATA_FOLDER_NAME = "midas_data"
+DATA_DIR_NAME = "midas_data"
+SCENARIO_DIR_NAME = "midas_scenarios"
+OUTPUT_DIR_NAME = "_outputs"
 DEFAULT_BASE_CONFIG = {
     "paths": {
         "data_path": (
-            f"{appdirs.user_config_dir('midas', 'OFFIS')}/midas_data"
+            f"{appdirs.user_config_dir('midas', 'OFFIS')}/{DATA_DIR_NAME}"
         ),
         # "output_path": f"{getcwd()}/_outputs",
-        "output_path": "_outputs",
+        "output_path": OUTPUT_DIR_NAME,
         "scenario_path": (
-            f"{appdirs.user_config_dir('midas', 'OFFIS')}/midas_scenarios"
+            f"{appdirs.user_config_dir('midas', 'OFFIS')}/{SCENARIO_DIR_NAME}"
         ),
     },
     "data": {
